PythonKeyword

Enum PythonKeyword 

pub enum PythonKeyword {
Show 35 variants False, None, True, And, As, Assert, Async, Await, Break, Class, Continue, Def, Del, Elif, Else, Except, Finally, For, From, Global, If, Import, In, Is, Lambda, Nonlocal, Not, Or, Pass, Raise, Return, Try, While, With, Yield,
}
Common hard Python keywords.

Variants



False



None



True



And



As



Assert



Async



Await



Break



Class



Continue



Def



Del



Elif



Else



Except



Finally



For



From



Global



If



Import



In



Is



Lambda



Nonlocal



Not



Or



Pass



Raise



Return



Try



While



With



Yield

Implementations

Source

impl PythonKeyword

pub const fn as_str(self) -> &'static str

Returns the Python source spelling for this keyword.